@@ -10,9 +10,8 @@
 #include "identity.h"
 #include "signaturerichtexteditor_p.h"
 
-#include "kidentitymanagement_debug.h"
 #include <KActionCollection>
-#include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KLineEdit>
 #include <KLocalizedString>
@@ -427,7 +426,7 @@ void SignatureConfigurator::slotEdit()
     assert(!url.isEmpty());
 
     auto job = new KIO::OpenUrlJob(QUrl::fromLocalFile(url), QStringLiteral("text/plain"));
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
     job->setDeleteTemporaryFile(true);
     job->start();
 }
